'use strict';

var index = require('./index-DnF1G--N.js');
var EventBus = require('./EventBus-Dq4GLNJp.js');
var signTransactionsPanelStore = require('./signTransactionsPanelStore-BO_c11Oi.js');

var SignEventsEnum;
(function (SignEventsEnum) {
    SignEventsEnum["CONFIRM"] = "CONFIRM";
    SignEventsEnum["BACK"] = "BACK";
    SignEventsEnum["DATA_UPDATE"] = "DATA_UPDATE";
    SignEventsEnum["SET_PPU"] = "SET_PPU";
    SignEventsEnum["OPEN_SIGN_TRANSACTIONS_PANEL"] = "OPEN_SIGN_TRANSACTIONS_PANEL";
    SignEventsEnum["CLOSE_SIGN_TRANSACTIONS_PANEL"] = "CLOSE_SIGN_TRANSACTIONS_PANEL";
})(SignEventsEnum || (SignEventsEnum = {}));

const signTransactionsPanelCss = "/*! tailwindcss v4.1.3 | MIT License | https://tailwindcss.com */@layer theme{:host,:root{--mvx-font-sans:ui-sans-serif,system-ui,sans-serif,\"Apple Color Emoji\",\"Segoe UI Emoji\",\"Segoe UI Symbol\",\"Noto Color Emoji\";--mvx-font-mono:ui-monospace,SFMono-Regular,Menlo,Monaco,Consolas,\"Liberation Mono\",\"Courier New\",monospace;--mvx-default-font-family:var(--mvx-font-sans);--mvx-default-mono-font-family:var(--mvx-font-mono)}}@layer base{*,::backdrop,:after,:before{border:0 solid;box-sizing:border-box;margin:0;padding:0}::file-selector-button{appearance:button;background-color:#0000;border:0 solid;border-radius:0;box-sizing:border-box;color:inherit;font:inherit;font-feature-settings:inherit;font-variation-settings:inherit;letter-spacing:inherit;margin:0;margin-inline-end:4px;opacity:1;padding:0}:host,html{-webkit-text-size-adjust:100%;font-family:var(--mvx-default-font-family,ui-sans-serif,system-ui,sans-serif,\"Apple Color Emoji\",\"Segoe UI Emoji\",\"Segoe UI Symbol\",\"Noto Color Emoji\");font-feature-settings:var(--mvx-default-font-feature-settings,normal);font-variation-settings:var(--mvx-default-font-variation-settings,normal);line-height:1.5;tab-size:4;-webkit-tap-highlight-color:transparent}hr{border-top-width:1px;color:inherit;height:0}abbr:where([title]){-webkit-text-decoration:underline dotted;text-decoration:underline dotted}h1,h2,h3,h4,h5,h6{font-size:inherit;font-weight:inherit}a{color:inherit;-webkit-text-decoration:inherit;text-decoration:inherit}b,strong{font-weight:bolder}code,kbd,pre,samp{font-family:var(--mvx-default-mono-font-family,ui-monospace,SFMono-Regular,Menlo,Monaco,Consolas,\"Liberation Mono\",\"Courier New\",monospace);font-feature-settings:var(--mvx-default-mono-font-feature-settings,normal);font-size:1em;font-variation-settings:var(--mvx-default-mono-font-variation-settings,normal)}small{font-size:80%}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline}sub{bottom:-.25em}sup{top:-.5em}table{border-collapse:collapse;border-color:inherit;text-indent:0}:-moz-focusring{outline:auto}progress{vertical-align:baseline}summary{display:list-item}menu,ol,ul{list-style:none}audio,canvas,embed,iframe,img,object,svg,video{display:block;vertical-align:middle}img,video{height:auto;max-width:100%}button,input,optgroup,select,textarea{background-color:#0000;border-radius:0;color:inherit;font:inherit;font-feature-settings:inherit;font-variation-settings:inherit;letter-spacing:inherit;opacity:1}:where(select:is([multiple],[size])) optgroup{font-weight:bolder}:where(select:is([multiple],[size])) optgroup option{padding-inline-start:20px}::placeholder{opacity:1}@supports (not ((-webkit-appearance:-apple-pay-button))) or (contain-intrinsic-size:1px){::placeholder{color:currentColor}@supports (color:color-mix(in lab,red,red)){::placeholder{color:color-mix(in oklab,currentColor 50%,transparent)}}}textarea{resize:vertical}::-webkit-search-decoration{-webkit-appearance:none}::-webkit-date-and-time-value{min-height:1lh;text-align:inherit}::-webkit-datetime-edit{display:inline-flex;padding-block:0}::-webkit-datetime-edit-fields-wrapper{padding:0}::-webkit-datetime-edit-month-field,::-webkit-datetime-edit-year-field{padding-block:0}::-webkit-datetime-edit-day-field,::-webkit-datetime-edit-hour-field{padding-block:0}::-webkit-datetime-edit-minute-field,::-webkit-datetime-edit-second-field{padding-block:0}::-webkit-datetime-edit-meridiem-field,::-webkit-datetime-edit-millisecond-field{padding-block:0}:-moz-ui-invalid{box-shadow:none}button,input:where([type=button],[type=reset],[type=submit]){appearance:button}::-webkit-inner-spin-button,::-webkit-outer-spin-button{height:auto}[hidden]:where(:not([hidden=until-found])){display:none!important}}@layer components,utilities; /*! tailwindcss v4.1.3 | MIT License | https://tailwindcss.com */@layer base{}@layer components,utilities;.transaction-header-container{display:flex;flex-direction:column}.loading-spinner{align-items:center;display:flex;justify-content:center;min-height:350px}.sign-transactions-panel{background-color:#fff;box-shadow:0 4px 12px #00000026;max-width:100%;padding:0;width:450px}.sign-transactions-content{display:flex;flex-direction:column;height:100%;padding:24px}.sign-transactions-header{border-bottom:1px solid #0000001a;margin-bottom:24px;padding-bottom:16px}.sign-transactions-header h2{font-size:20px;font-weight:600;margin-bottom:8px}.sign-transactions-header h4{color:#0009;font-size:14px;font-weight:400}.sign-transactions-body{flex:1;overflow-y:auto}";

const signScreens = {
    FungibleESDT: 'token-component',
    SemiFungibleESDT: 'fungible-component',
    NonFungibleESDT: 'fungible-component',
    MetaESDT: 'token-component',
};
const SignTransactionsPanel = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.eventBus = new EventBus.EventBus();
        this.isOpen = false;
        this.data = {
            commonData: {
                egldLabel: '',
                feeLimit: '',
                feeInFiatLimit: '',
                transactionsCount: 0,
                currentIndex: 0,
                ppuOptions: [],
            },
            tokenTransaction: null,
            nftTransaction: null,
            sftTransaction: null,
        };
    }
    componentWillLoad() {
        signTransactionsPanelStore.state.onCancel = () => {
            this.onClose({ isUserClick: true });
        };
        signTransactionsPanelStore.state.onConfirm = () => {
            this.eventBus.publish(SignEventsEnum.CONFIRM);
        };
        signTransactionsPanelStore.state.onBack = () => {
            this.eventBus.publish(SignEventsEnum.BACK);
        };
        signTransactionsPanelStore.state.onSetPpu = (ppu) => {
            this.eventBus.publish(SignEventsEnum.SET_PPU, ppu);
        };
    }
    componentDidLoad() {
        this.eventBus.subscribe(SignEventsEnum.DATA_UPDATE, this.dataUpdate.bind(this));
        this.eventBus.subscribe(SignEventsEnum.OPEN_SIGN_TRANSACTIONS_PANEL, this.handleOpen.bind(this));
        this.eventBus.subscribe(SignEventsEnum.CLOSE_SIGN_TRANSACTIONS_PANEL, this.onClose.bind(this, { isUserClick: false }));
    }
    disconnectedCallback() {
        signTransactionsPanelStore.resetState();
        this.eventBus.unsubscribe(SignEventsEnum.DATA_UPDATE, this.dataUpdate.bind(this));
        this.eventBus.unsubscribe(SignEventsEnum.OPEN_SIGN_TRANSACTIONS_PANEL, this.handleOpen.bind(this));
        this.eventBus.unsubscribe(SignEventsEnum.CLOSE_SIGN_TRANSACTIONS_PANEL, this.onClose.bind(this, { isUserClick: false }));
    }
    handleOpen() {
        this.isOpen = true;
    }
    handleClose() {
        this.isOpen = false;
        this.onClose({ isUserClick: true });
    }
    onClose(props = { isUserClick: true }) {
        this.isOpen = false;
        signTransactionsPanelStore.resetState();
        if (props.isUserClick) {
            this.eventBus.publish(SignEventsEnum.CLOSE_SIGN_TRANSACTIONS_PANEL);
        }
    }
    dataUpdate(payload) {
        this.data = Object.assign({}, payload);
        index.forceUpdate(this);
    }
    onDataChange(data) {
        for (const key in data) {
            if (Object.prototype.hasOwnProperty.call(signTransactionsPanelStore.state, key)) {
                signTransactionsPanelStore.state[key] = data[key];
            }
        }
        signTransactionsPanelStore.state.isWaitingForSignature = false;
        signTransactionsPanelStore.state.isLoading = false;
    }
    async getEventBus() {
        return this.eventBus;
    }
    render() {
        const { commonData, isLoading } = signTransactionsPanelStore.state;
        const { tokenType, currentIndex, transactionsCount } = commonData;
        const SignScreen = signScreens[tokenType];
        return (index.h("mvx-side-panel", { key: '509b13edb464c57199f961740bd9d83149434064', isOpen: this.isOpen, panelClassName: "sign-transactions-panel", onClose: this.handleClose.bind(this) }, index.h("div", { key: 'aa929cfd9f98130efd7431d713a4a45a3df08dca', class: "sign-transactions-content" }, index.h("div", { key: '62fa7f9f7052724d8493a15544a80c44c73b1b65', class: "sign-transactions-header" }, index.h("h2", { key: '908edd8f9f07b4485a2711053a7807ed02dbb3d1' }, "Sign transaction"), index.h("h4", { key: '80bb8619e0480b3e7314c3718ffdd4b305e36f0d' }, "Transaction ", currentIndex + 1, " of ", transactionsCount)), index.h("div", { key: '188051f296c564f7cd1a2c9a157829a11ee8419c', class: "sign-transactions-body" }, isLoading ? (index.h("div", { class: "loading-spinner" }, index.h("mvx-generic-spinner", null))) : (index.h(SignScreen, null))))));
    }
    static get watchers() { return {
        "data": ["onDataChange"]
    }; }
};
SignTransactionsPanel.style = signTransactionsPanelCss;

exports.mvx_sign_transactions_panel = SignTransactionsPanel;
//# sourceMappingURL=mvx-sign-transactions-panel.entry.cjs.js.map

//# sourceMappingURL=mvx-sign-transactions-panel.cjs.entry.js.map