import { faInfoCircle } from "@fortawesome/free-solid-svg-icons";
import { h } from "@stencil/core";
import { EventBus } from "../../../utils/EventBus";
import { NotificationsFeedEventsEnum } from "./notifications-feed.types";
export class NotificationsFeed {
    constructor() {
        this.isOpen = false;
        this.pendingTransactions = [];
        this.transactionsHistory = [];
        this.eventBus = new EventBus();
        this.closeEventTimeout = null;
        this.handleClose = () => {
            this.isOpen = false;
            this.eventBus.publish(NotificationsFeedEventsEnum.CLOSE_NOTIFICATIONS_FEED);
        };
        this.handleClear = () => {
            this.eventBus.publish(NotificationsFeedEventsEnum.CLEAR_NOTIFICATIONS_FEED_HISTORY);
        };
        this.handleViewAll = () => {
            this.isOpen = true;
        };
    }
    clearTimeouts() {
        if (this.closeEventTimeout) {
            clearTimeout(this.closeEventTimeout);
            this.closeEventTimeout = null;
        }
    }
    disconnectedCallback() {
        this.clearTimeouts();
        this.eventBus.unsubscribe(NotificationsFeedEventsEnum.PENDING_TRANSACTIONS_UPDATE, this.pendingTransactionsUpdate.bind(this));
        this.eventBus.unsubscribe(NotificationsFeedEventsEnum.TRANSACTIONS_HISTORY_UPDATE, this.transactionsHistoryUpdate.bind(this));
        this.eventBus.unsubscribe(NotificationsFeedEventsEnum.OPEN_NOTIFICATIONS_FEED, this.handleViewAll.bind(this));
    }
    async getEventBus() {
        return this.eventBus;
    }
    render() {
        var _a, _b, _c;
        const hasActivity = ((_a = this.transactionsHistory) === null || _a === void 0 ? void 0 : _a.length) > 0;
        const hasPending = ((_b = this.pendingTransactions) === null || _b === void 0 ? void 0 : _b.length) > 0;
        return (h("mvx-side-panel", { key: '99dfc791337bed6050076c790123155f14e0cd97', isOpen: this.isOpen, panelTitle: "Notifications Feed", onClose: this.handleClose }, h("div", { key: '1bc2f2f3995d15d36f54aac458b9b398d0352d7b', class: "feed-content" }, h("div", { key: '67ff42bad476a37fa7d130859de3c4e9be998c1c', class: "notifications-info" }, h("mvx-fa-icon", { key: '2fd1802a8328c65e26625fc61a50a47f2a60620a', class: "info-icon", icon: faInfoCircle }), "This feed is stored in your browser and will be reset when a new session is started.", h("fa-icon", { key: '36828db6493628a5e2373400fbc45ba58ff625c4', class: "info-icon", icon: faInfoCircle })), hasPending && (h("div", { key: '610155bdc25b3a13033062f2283f759212235227', class: "notifications-container" }, h("div", { key: '1387fad9c3a2bfcba5f0234f195c07240c34baec', class: "processing-status" }, "Processing..."), (_c = this.pendingTransactions) === null || _c === void 0 ? void 0 :
            _c.map(toast => h("mvx-transaction-toast", Object.assign({ fullWidth: true }, toast))))), h("div", { key: '21b41df8e7c3eb9da0e7bf9709c97a494a64b9f7', class: "activity-section" }, h("div", { key: 'f40c84a2e57609557aefa3926ade596cfe8f919e', class: "activity-header" }, h("h3", { key: '2077cbdd8813d3b9e7b6b8dc10d6f928dca3ef0d', class: "activity-title" }, "Activity"), hasActivity && (h("button", { key: 'e7a4f805bfc0e0fe35fbedf855a3e924fdeffb4d', class: "clear-button", onClick: this.handleClear }, "Clear"))), h("div", { key: '2674a447e8673aefc6a0d285d27b0e6ad13d6478', class: "activity-list" }, hasActivity ? (this.transactionsHistory.map(transaction => h("mvx-transaction-list-item", { transaction: transaction }))) : (h("div", { class: "no-activity" }, "No activity to show")))))));
    }
    pendingTransactionsUpdate(payload) {
        this.pendingTransactions = [...payload];
    }
    transactionsHistoryUpdate(payload) {
        this.transactionsHistory = [...payload];
    }
    componentDidLoad() {
        this.eventBus.subscribe(NotificationsFeedEventsEnum.PENDING_TRANSACTIONS_UPDATE, this.pendingTransactionsUpdate.bind(this));
        this.eventBus.subscribe(NotificationsFeedEventsEnum.TRANSACTIONS_HISTORY_UPDATE, this.transactionsHistoryUpdate.bind(this));
        this.eventBus.subscribe(NotificationsFeedEventsEnum.OPEN_NOTIFICATIONS_FEED, this.handleViewAll.bind(this));
    }
    static get is() { return "mvx-notifications-feed"; }
    static get originalStyleUrls() {
        return {
            "$": ["notifications-feed.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["notifications-feed.css"]
        };
    }
    static get states() {
        return {
            "isOpen": {},
            "pendingTransactions": {},
            "transactionsHistory": {}
        };
    }
    static get methods() {
        return {
            "getEventBus": {
                "complexType": {
                    "signature": "() => Promise<IEventBus>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "IEventBus": {
                            "location": "import",
                            "path": "utils/EventBus",
                            "id": "src/utils/EventBus.ts::IEventBus"
                        }
                    },
                    "return": "Promise<IEventBus>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
}
//# sourceMappingURL=notifications-feed.js.map
