import { forceUpdate, h } from "@stencil/core";
import { DataTestIdsEnum } from "../../../constants/dataTestIds.enum";
import { EventBus } from "../../../utils/EventBus";
import { PendingTransactionsEventsEnum } from "./pending-transactions-panel.types";
export class PendingTransactionstPanel {
    constructor() {
        this.eventBus = new EventBus();
        this.isOpen = false;
        this.data = {
            isPending: false,
            title: '',
            subtitle: '',
        };
    }
    componentDidLoad() {
        this.eventBus.subscribe(PendingTransactionsEventsEnum.DATA_UPDATE, this.dataUpdate.bind(this));
        this.eventBus.subscribe(PendingTransactionsEventsEnum.OPEN_PENDING_TRANSACTIONS_PANEL, this.handleOpen.bind(this));
        this.eventBus.subscribe(PendingTransactionsEventsEnum.CLOSE_PENDING_TRANSACTIONS, this.onClose.bind(this, { isUserClick: false }));
    }
    disconnectedCallback() {
        this.eventBus.unsubscribe(PendingTransactionsEventsEnum.DATA_UPDATE, this.dataUpdate.bind(this));
        this.eventBus.unsubscribe(PendingTransactionsEventsEnum.OPEN_PENDING_TRANSACTIONS_PANEL, this.handleOpen.bind(this));
        this.eventBus.unsubscribe(PendingTransactionsEventsEnum.CLOSE_PENDING_TRANSACTIONS, this.onClose.bind(this, { isUserClick: false }));
    }
    handleOpen() {
        this.isOpen = true;
    }
    handleClose() {
        this.isOpen = false;
        this.onClose({ isUserClick: true });
    }
    onClose(props = { isUserClick: true }) {
        this.isOpen = false;
        if (props.isUserClick) {
            this.eventBus.publish(PendingTransactionsEventsEnum.CLOSE_PENDING_TRANSACTIONS);
        }
    }
    dataUpdate(payload) {
        if (payload.shouldClose) {
            return this.onClose({ isUserClick: false });
        }
        this.isOpen = true;
        this.data = Object.assign({}, payload);
        forceUpdate(this);
    }
    async getEventBus() {
        return this.eventBus;
    }
    render() {
        return (h("mvx-side-panel", { key: '42a4bc2bd3b57507d52ef4550ed15dea00609d68', isOpen: this.isOpen, panelClassName: "pending-transactions-panel", onClose: this.handleClose.bind(this) }, h("div", { key: '2c9bb3f18832c12dbe46599a3d950e7a0eccef59', class: "pending-transactions-content" }, h("div", { key: '60afbf307622f1a356e81cd3d44e168f4f141a08', class: "pending-transactions-header" }, h("h2", { key: '931b2fbe92106000a890f17b400171c3ba6841b8', "data-testid": DataTestIdsEnum.pendingTransactionsTitle }, this.data.title), h("h4", { key: '4d456d9e0c69a670f78669678e5f50140829ccde', "data-testid": DataTestIdsEnum.pendingTransactionsSubtitle }, this.data.subtitle)), h("div", { key: 'e36fdf0d85803beeca9e2a6f797e91d8306d4bd5', class: "pending-transactions-body" }, h("button", { key: '821b4b9e1f1ef2b19c8af9b413e2dc2bd9eab72c', class: "close-button", onClick: this.handleClose.bind(this) }, "Close")))));
    }
    static get is() { return "mvx-pending-transactions-panel"; }
    static get originalStyleUrls() {
        return {
            "$": ["pending-transactions-panel.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["pending-transactions-panel.css"]
        };
    }
    static get properties() {
        return {
            "data": {
                "type": "unknown",
                "attribute": "data",
                "mutable": false,
                "complexType": {
                    "original": "IPendingTransactionsPanelData",
                    "resolved": "IPendingTransactionsPanelData",
                    "references": {
                        "IPendingTransactionsPanelData": {
                            "location": "import",
                            "path": "./pending-transactions-panel.types",
                            "id": "src/components/functional/pending-transactions-panel/pending-transactions-panel.types.ts::IPendingTransactionsPanelData"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "defaultValue": "{\n    isPending: false,\n    title: '',\n    subtitle: '',\n  }"
            }
        };
    }
    static get states() {
        return {
            "isOpen": {}
        };
    }
    static get methods() {
        return {
            "getEventBus": {
                "complexType": {
                    "signature": "() => Promise<IEventBus>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "IEventBus": {
                            "location": "import",
                            "path": "utils/EventBus",
                            "id": "src/utils/EventBus.ts::IEventBus"
                        }
                    },
                    "return": "Promise<IEventBus>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
}
//# sourceMappingURL=pending-transactions-panel.js.map
