import { Fragment, h } from "@stencil/core";
import classNames from "classnames";
const DEFAULT_INFINITE_ANIMATION_DURATION = 30;
export class ToastProgress {
    constructor() {
        this.currentTimestamp = Date.now() / 1000;
        this.hasTimeElapsed = false;
        this.expectedTransactionDuration = 0;
        this.secondsPassedSinceStart = 0;
        this.shouldShowProgressBar = false;
        this.percentagePassedSinceStart = 0;
        this.shouldQuickFill = false;
        this.infiniteProgressDelay = 0;
        this.infinitePercentagePassedSinceStart = 0;
        this.infinitePercentageAnimationDuration = DEFAULT_INFINITE_ANIMATION_DURATION + (this.endTime - this.startTime) * 2;
    }
    componentWillLoad() {
        this.updateProgress();
    }
    handleTimeChange() {
        this.updateProgress();
    }
    updateProgress() {
        this.shouldShowProgressBar = Boolean(this.endTime) && Boolean(this.startTime);
        if (!this.shouldShowProgressBar) {
            this.shouldQuickFill = true;
            this.timeElapsedTimeoutReference = setTimeout(() => (this.hasTimeElapsed = true), 500);
            return;
        }
        this.currentTimestamp = Date.now() / 1000;
        this.expectedTransactionDuration = this.endTime - this.startTime;
        this.secondsPassedSinceStart = this.currentTimestamp - this.startTime;
        this.percentagePassedSinceStart = this.expectedTransactionDuration > 0 ? (this.secondsPassedSinceStart / this.expectedTransactionDuration) * 100 : 0;
        this.infiniteProgressDelay = Math.max(0, this.expectedTransactionDuration - this.secondsPassedSinceStart);
        this.infinitePercentagePassedSinceStart = (this.secondsPassedSinceStart / (this.expectedTransactionDuration + this.infinitePercentageAnimationDuration)) * 100;
    }
    disconnectedCallback() {
        if (this.timeElapsedTimeoutReference) {
            clearTimeout(this.timeElapsedTimeoutReference);
        }
    }
    render() {
        return (h(Fragment, { key: 'db63fa5477f9821fe10d93ca87b50a9ba911609a' }, h("div", { key: '21dd676a9c365e393e0d5fc470befd6fd9f39ce6', class: "transaction-toast-bar-wrapper", style: { opacity: this.hasTimeElapsed ? '0' : '1' } }, h("div", { key: '7ad99e0a6120682d37d51d5832db5836879c6636', class: "transaction-toast-bar-fixed", style: {
                '--animation-duration': `${this.expectedTransactionDuration}s`,
                '--start-width': `${this.percentagePassedSinceStart}%`,
            } }), h("div", { key: '1f8dad80201e843d6aa0f54e720d88337419938d', class: "transaction-toast-bar infinite" }, h("div", { key: '28b9b224f3295d7613d2d4a805a7b2972b3c130e', class: "transaction-toast-bar-line", style: {
                '--start-width': `${this.infinitePercentagePassedSinceStart}%`,
                '--animation-duration': `${this.infinitePercentageAnimationDuration}s`,
                '--animation-delay': `${this.infiniteProgressDelay}s`,
            } })), h("div", { key: '3f5ba0353ca631bb472ff853bd9fd0727d0dee61', class: classNames('transaction-toast-bar fill', {
                animate: this.shouldQuickFill,
            }) })), h("div", { key: 'a15a928b91812e32b9536537235b06231b14f391', class: "transaction-toast-bar-content" }, h("slot", { key: '5d4c02111114b4b48d6ec32d4dc5e9fa35027402' }))));
    }
    static get is() { return "mvx-transaction-toast-progress"; }
    static get originalStyleUrls() {
        return {
            "$": ["transaction-toast-progress.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["transaction-toast-progress.css"]
        };
    }
    static get properties() {
        return {
            "startTime": {
                "type": "number",
                "attribute": "start-time",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "endTime": {
                "type": "number",
                "attribute": "end-time",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "currentTimestamp": {},
            "hasTimeElapsed": {},
            "expectedTransactionDuration": {},
            "secondsPassedSinceStart": {},
            "shouldShowProgressBar": {},
            "percentagePassedSinceStart": {},
            "shouldQuickFill": {},
            "infiniteProgressDelay": {},
            "infinitePercentagePassedSinceStart": {},
            "infinitePercentageAnimationDuration": {}
        };
    }
    static get watchers() {
        return [{
                "propName": "startTime",
                "methodName": "handleTimeChange"
            }, {
                "propName": "endTime",
                "methodName": "handleTimeChange"
            }];
    }
}
//# sourceMappingURL=transaction-toast-progress.js.map
