import { forceUpdate, h } from "@stencil/core";
import { DataTestIdsEnum } from "../../../constants/dataTestIds.enum";
import { WalletConnectEventsEnum } from "./wallet-connect-panel.types";
import { WalletConnectBase } from "./WalletConnectBase";
export class WalletConnectPanel {
    constructor() {
        this.data = {
            wcURI: '',
        };
        this.qrCodeSvg = '';
        this.isOpen = false;
        this.walletConnectBase = new WalletConnectBase(this.data);
    }
    componentDidLoad() {
        this.walletConnectBase.subscribeEventBus(this.getEventBusSubscription());
        this.walletConnectBase.eventBus.subscribe(WalletConnectEventsEnum.OPEN_WALLET_CONNECT_PANEL, this.handleOpen.bind(this));
        this.walletConnectBase.eventBus.subscribe(WalletConnectEventsEnum.CLOSE_WALLET_CONNECT_PANEL, this.onClose.bind(this, { isUserClick: false }));
    }
    disconnectedCallback() {
        this.walletConnectBase.unsubscribeEventBus(this.getEventBusSubscription());
        this.walletConnectBase.eventBus.unsubscribe(WalletConnectEventsEnum.OPEN_WALLET_CONNECT_PANEL, this.handleOpen.bind(this));
        this.walletConnectBase.eventBus.unsubscribe(WalletConnectEventsEnum.CLOSE_WALLET_CONNECT_PANEL, this.onClose.bind(this, { isUserClick: false }));
    }
    handleOpen() {
        this.isOpen = true;
    }
    handleClose() {
        this.isOpen = false;
        this.onClose({ isUserClick: true });
    }
    onClose(props = { isUserClick: true }) {
        this.isOpen = false;
        if (props.isUserClick) {
            this.walletConnectBase.eventBus.publish(WalletConnectEventsEnum.CLOSE_WALLET_CONNECT_PANEL);
        }
    }
    async getEventBus() {
        return this.walletConnectBase.getEventBus();
    }
    getEventBusSubscription() {
        return {
            closeFn: () => this.onClose({ isUserClick: false }),
            forceUpdateFn: () => {
                this.data = this.walletConnectBase.data;
                forceUpdate(this);
            },
        };
    }
    async onDataChange(data) {
        if (data.wcURI) {
            this.qrCodeSvg = await this.walletConnectBase.generateSVG(data.wcURI);
        }
    }
    render() {
        return (h("mvx-side-panel", { key: '4cc915a96e400eb932dfa8d8a7314310b0337eac', isOpen: this.isOpen, panelClassName: "wallet-connect-side-panel", onClose: this.handleClose.bind(this) }, h("div", { key: '92145b9870ede327c94c19fbf252c4ae1f12201b', class: "wallet-connect-container" }, h("div", { key: '314a818d61809ac55d5d03bc21068b2c6b238f01', class: "wallet-connect-header" }, h("h2", { key: '4260f1295a8b58def87fac4bd125fdbf4b79a6f8', "data-testid": DataTestIdsEnum.walletConnetModalTitle }, "xPortal Mobile Wallet"), h("h4", { key: 'd48b9968f06a90457e1ae07e341a09a33ef54305', "data-testid": DataTestIdsEnum.walletConnetModalSubtitle }, "Scan this QR code with your app")), h("mvx-wallet-connect-body", { key: 'a01da11dea4f1967266e958e30b99928f1097668', qrCodeSvg: this.qrCodeSvg }))));
    }
    static get is() { return "mvx-wallet-connect-panel"; }
    static get originalStyleUrls() {
        return {
            "$": ["wallet-connect-panel.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["wallet-connect-panel.css"]
        };
    }
    static get properties() {
        return {
            "data": {
                "type": "unknown",
                "attribute": "data",
                "mutable": false,
                "complexType": {
                    "original": "IWalletConnectPanelData",
                    "resolved": "IWalletConnectPanelData",
                    "references": {
                        "IWalletConnectPanelData": {
                            "location": "import",
                            "path": "./wallet-connect-panel.types",
                            "id": "src/components/functional/wallet-connect-components/wallet-connect-panel.types.ts::IWalletConnectPanelData"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "defaultValue": "{\n    wcURI: '',\n  }"
            }
        };
    }
    static get states() {
        return {
            "qrCodeSvg": {},
            "isOpen": {}
        };
    }
    static get methods() {
        return {
            "getEventBus": {
                "complexType": {
                    "signature": "() => Promise<IEventBus>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "IEventBus": {
                            "location": "import",
                            "path": "utils/EventBus",
                            "id": "src/utils/EventBus.ts::IEventBus"
                        }
                    },
                    "return": "Promise<IEventBus>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "hostElement"; }
    static get watchers() {
        return [{
                "propName": "data",
                "methodName": "onDataChange"
            }];
    }
}
//# sourceMappingURL=wallet-connect-panel.js.map
