import { forceUpdate, h } from "@stencil/core";
import { WalletConnectBase } from "./WalletConnectBase";
export class WalletConnect {
    constructor() {
        this.data = {
            wcURI: '',
        };
        this.qrCodeSvg = '';
    }
    componentWillLoad() {
        this.walletConnectBase = new WalletConnectBase(this.data);
    }
    async getEventBus() {
        return this.walletConnectBase.getEventBus();
    }
    async onDataChange(data) {
        if (data.wcURI) {
            this.qrCodeSvg = await this.walletConnectBase.generateSVG(data.wcURI);
        }
    }
    render() {
        return h("mvx-wallet-connect-body", { key: 'c7990726ccb0dd5099930efd988c18fc9dc59dd2', qrCodeSvg: this.qrCodeSvg, description: "Scan this QR using xPortal" });
    }
    removeComponent() {
        var _a;
        if ((_a = this.hostElement) === null || _a === void 0 ? void 0 : _a.parentNode) {
            this.hostElement.parentNode.removeChild(this.hostElement);
        }
    }
    getEventSubscription() {
        return {
            closeFn: () => this.removeComponent(),
            forceUpdateFn: () => {
                this.data = this.walletConnectBase.data;
                forceUpdate(this);
            },
        };
    }
    componentDidLoad() {
        this.walletConnectBase.subscribeEventBus(this.getEventSubscription());
    }
    disconnectedCallback() {
        this.walletConnectBase.unsubscribeEventBus(this.getEventSubscription());
    }
    static get is() { return "mvx-wallet-connect"; }
    static get properties() {
        return {
            "data": {
                "type": "unknown",
                "attribute": "data",
                "mutable": false,
                "complexType": {
                    "original": "IWalletConnectPanelData",
                    "resolved": "IWalletConnectPanelData",
                    "references": {
                        "IWalletConnectPanelData": {
                            "location": "import",
                            "path": "./wallet-connect-panel.types",
                            "id": "src/components/functional/wallet-connect-components/wallet-connect-panel.types.ts::IWalletConnectPanelData"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "defaultValue": "{\n    wcURI: '',\n  }"
            }
        };
    }
    static get states() {
        return {
            "qrCodeSvg": {}
        };
    }
    static get methods() {
        return {
            "getEventBus": {
                "complexType": {
                    "signature": "() => Promise<IEventBus>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "IEventBus": {
                            "location": "import",
                            "path": "utils/EventBus",
                            "id": "src/utils/EventBus.ts::IEventBus"
                        }
                    },
                    "return": "Promise<IEventBus>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "hostElement"; }
    static get watchers() {
        return [{
                "propName": "data",
                "methodName": "onDataChange"
            }];
    }
}
//# sourceMappingURL=wallet-connect.js.map
