import { Fragment, h } from "@stencil/core";
import { ProviderTypeEnum } from "../../../../../types/provider.types";
var ProviderButtonLabelsEnum;
(function (ProviderButtonLabelsEnum) {
    ProviderButtonLabelsEnum["extension"] = "MultiversX Wallet Extension";
    ProviderButtonLabelsEnum["metamask"] = "MetaMask Snap";
    ProviderButtonLabelsEnum["passkey"] = "Passkey";
    ProviderButtonLabelsEnum["xportal"] = "xPortal Wallet";
    ProviderButtonLabelsEnum["ledger"] = "Ledger";
    ProviderButtonLabelsEnum["wallet"] = "MultiversX Web Wallet";
    ProviderButtonLabelsEnum["xalias"] = "Google (xAlias)";
})(ProviderButtonLabelsEnum || (ProviderButtonLabelsEnum = {}));
const providerButtonInfo = {
    [ProviderTypeEnum.extension]: {
        icon: h("mvx-extension-provider-icon", null),
        label: ProviderButtonLabelsEnum.extension,
    },
    [ProviderTypeEnum.metamask]: {
        icon: h("mvx-metamask-provider-icon", null),
        label: ProviderButtonLabelsEnum.metamask,
    },
    [ProviderTypeEnum.passkey]: {
        icon: h("mvx-passkey-provider-icon", null),
        label: ProviderButtonLabelsEnum.passkey,
    },
    [ProviderTypeEnum.walletConnect]: {
        icon: h("mvx-multiversx-logo-icon", null),
        label: ProviderButtonLabelsEnum.xportal,
    },
    [ProviderTypeEnum.ledger]: {
        icon: h("mvx-ledger-provider-icon", null),
        label: ProviderButtonLabelsEnum.ledger,
    },
    [ProviderTypeEnum.crossWindow]: {
        icon: h("mvx-wallet-provider-icon", null),
        label: ProviderButtonLabelsEnum.wallet,
    },
    [ProviderTypeEnum.xalias]: {
        icon: h("mvx-xalias-provider-icon", null),
        label: ProviderButtonLabelsEnum.xalias,
    },
};
export class ProviderButton {
    render() {
        const walletInfo = this.type ? providerButtonInfo[this.type] : null;
        if (!walletInfo) {
            return h(Fragment, null);
        }
        return h("mvx-unlock-button", { icon: walletInfo.icon, label: walletInfo.label, type: this.type, class: this.class });
    }
    static get is() { return "mvx-provider-button"; }
    static get originalStyleUrls() {
        return {
            "$": ["provider-button.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["provider-button.css"]
        };
    }
    static get properties() {
        return {
            "type": {
                "type": "string",
                "attribute": "type",
                "mutable": false,
                "complexType": {
                    "original": "ProviderTypeEnum",
                    "resolved": "ProviderTypeEnum.crossWindow | ProviderTypeEnum.extension | ProviderTypeEnum.ledger | ProviderTypeEnum.metamask | ProviderTypeEnum.passkey | ProviderTypeEnum.walletConnect | ProviderTypeEnum.xalias",
                    "references": {
                        "ProviderTypeEnum": {
                            "location": "import",
                            "path": "types/provider.types",
                            "id": "src/types/provider.types.ts::ProviderTypeEnum"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "class": {
                "type": "string",
                "attribute": "class",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
}
//# sourceMappingURL=provider-button.js.map
