import { h } from "@stencil/core";
import classNames from "classnames";
import { ProviderTypeEnum } from "../../../types/provider.types";
import { getIsExtensionAvailable, getIsMetaMaskAvailable } from "./helpers";
export class UnlockPanel {
    constructor() {
        this.isOpen = false;
        this.allowedProviders = Object.values(ProviderTypeEnum);
        this.isLoggingIn = false;
        this.selectedMethod = null;
        this.childElements = [];
        this.anchor = null;
        this.observer = null;
    }
    isExtensionInstalled(currentProvider) {
        return currentProvider === ProviderTypeEnum.extension && getIsExtensionAvailable();
    }
    isMetaMaskInstalled(currentProvider) {
        return currentProvider === ProviderTypeEnum.metamask && getIsMetaMaskAvailable();
    }
    disconnectedCallback() {
        if (this.observer) {
            this.observer.disconnect();
        }
    }
    observeContainer(element) {
        if (!element) {
            return;
        }
        this.anchor = element;
        if (this.observer) {
            this.observer.disconnect();
        }
        this.observer = new MutationObserver(() => {
            this.isLoggingIn = element.childElementCount > 0;
        });
        this.observer.observe(element, { childList: true, subtree: true });
    }
    handleLogin(provider) {
        this.login.emit({ provider, anchor: this.anchor });
        this.selectedMethod = provider;
    }
    handleResetLoginState(event) {
        event.preventDefault();
        this.isLoggingIn = false;
        this.selectedMethod = null;
        if (!this.anchor) {
            return;
        }
        while (this.anchor.firstChild) {
            this.anchor.removeChild(this.anchor.firstChild);
        }
    }
    handleClose(event) {
        event.preventDefault();
        this.close.emit();
    }
    componentWillLoad() {
        this.childElements = [...this.host.children];
        this.host.innerHTML = '';
    }
    render() {
        const detectedProviders = this.allowedProviders.filter(allowedProvider => this.isExtensionInstalled(allowedProvider) || this.isMetaMaskInstalled(allowedProvider));
        const otherProviders = this.allowedProviders.filter(allowedProvider => !detectedProviders.includes(allowedProvider));
        const hasDetectedProviders = detectedProviders.length > 0;
        return (h("mvx-side-panel", { key: '3bb5bbc0a6f8440406c23d4a3cd3522ad4b4fe48', isOpen: this.isOpen, panelTitle: "Connect your wallet", onClose: this.handleClose.bind(this), onBack: this.handleResetLoginState.bind(this), withBackButton: this.isLoggingIn }, h("div", { key: 'e68f258500c336ba4d4e3a889d487465bc645ef8', id: "anchor", ref: element => this.observeContainer(element) }), !this.isLoggingIn && (h("div", { key: '2ba4d2445de712de5a4e055b2f64140f40c368c1', class: "unlock-panel" }, h("div", { key: 'abc3dce32bf253b74708a11b44aeec8715839698', class: "unlock-panel-groups" }, hasDetectedProviders && (h("div", { key: '646af89c058e3246287da0ef7d1e1f4a7ed619cd', class: "unlock-panel-group" }, h("div", { key: '972964671544dd5aaba2de36e900647b39f9560f', class: "unlock-panel-group-label" }, "Detected"), h("div", { key: '4a9590a0f7f2f96dd07182251e4499a369940cf8', class: "unlock-panel-group-providers" }, detectedProviders.map((provider, providerIndex) => (h("mvx-provider-button", { type: provider, onClick: this.handleLogin.bind(this, provider), class: classNames('unlock-panel-group-provider', {
                first: providerIndex === 0,
                last: providerIndex === detectedProviders.length - 1,
            }) })))))), h("div", { key: '0e4fff0e774dbfd704f318345a245564e8e4ae56', class: "unlock-panel-group" }, h("div", { key: 'ec4b48b8ef9ef6667c20b742549aa7b96e183f47', class: "unlock-panel-group-label" }, hasDetectedProviders ? 'Other Options' : 'Options'), h("div", { key: 'c46eb572af03003fd45f770314f5857cf429abf1', class: "unlock-panel-group-providers" }, otherProviders.map((provider, providerIndex) => (h("mvx-provider-button", { type: provider, onClick: this.handleLogin.bind(this, provider), class: classNames('unlock-panel-group-provider', {
                first: providerIndex === 0,
                last: providerIndex === otherProviders.length - 1,
            }) })))))), h("div", { key: '97d72422ef8015b043e1fdceb83cbc62c78e7656' }, "External Providers", h("mxv-children", { key: 'ce1a6bb66221d5fdddc430b1dccf174eeaf8a774', innerHTML: this.childElements.map(childElement => childElement.innerHTML) })), h("img", { key: '0520a6262a66b91d6004e8df846362d133785b27', src: new URL('../collection/assets/unlock-panel-wallet.png', import.meta.url).href })))));
    }
    static get is() { return "mvx-unlock-panel"; }
    static get originalStyleUrls() {
        return {
            "$": ["unlock-panel.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["unlock-panel.css"]
        };
    }
    static get properties() {
        return {
            "isOpen": {
                "type": "boolean",
                "attribute": "is-open",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "allowedProviders": {
                "type": "unknown",
                "attribute": "allowed-providers",
                "mutable": false,
                "complexType": {
                    "original": "ProviderTypeEnum[]",
                    "resolved": "ProviderTypeEnum[]",
                    "references": {
                        "ProviderTypeEnum": {
                            "location": "import",
                            "path": "types/provider.types",
                            "id": "src/types/provider.types.ts::ProviderTypeEnum"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "defaultValue": "Object.values(ProviderTypeEnum)"
            }
        };
    }
    static get states() {
        return {
            "isLoggingIn": {},
            "selectedMethod": {},
            "childElements": {}
        };
    }
    static get events() {
        return [{
                "method": "close",
                "name": "close",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "login",
                "name": "login",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "{ provider: ProviderTypeEnum; anchor?: HTMLElement }",
                    "resolved": "{ provider: ProviderTypeEnum; anchor?: HTMLElement; }",
                    "references": {
                        "ProviderTypeEnum": {
                            "location": "import",
                            "path": "types/provider.types",
                            "id": "src/types/provider.types.ts::ProviderTypeEnum"
                        },
                        "HTMLElement": {
                            "location": "global",
                            "id": "global::HTMLElement"
                        }
                    }
                }
            }];
    }
    static get elementRef() { return "host"; }
}
//# sourceMappingURL=unlock-panel.js.map
