import { r as registerInstance, h, f as forceUpdate, g as getElement } from './index-D3R9UMmk.js';
import { L as LedgerConnectBase, a as LedgerConnectEventsEnum } from './LedgerConnectBase-C_QIdNvO.js';
import './EventBus-S9juR7eS.js';

const LedgerConnect = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.data = {
            accountScreenData: null,
            confirmScreenData: null,
            connectScreenData: {},
        };
        this.selectedIndex = 0;
    }
    componentWillLoad() {
        this.ledgerConnectBase = new LedgerConnectBase(this.data);
    }
    async getEventBus() {
        return this.ledgerConnectBase.getEventBus();
    }
    render() {
        const { accountScreenData, confirmScreenData, connectScreenData } = this.data;
        if (accountScreenData) {
            return (h("mvx-ledger-account-screen", { accountScreenData: accountScreenData, selectedIndex: this.selectedIndex, onSelectAccount: (event) => this.selectAccount(event.detail), onAccessWallet: () => this.accessWallet(), onPrevPage: () => this.prevPage(), onNextPage: () => this.nextPage() }));
        }
        if (confirmScreenData) {
            return h("mvx-ledger-confirm-screen", { confirmScreenData: confirmScreenData });
        }
        return h("mvx-ledger-connect-screen", { connectScreenData: connectScreenData, onConnect: () => this.ledgerConnectBase.eventBus.publish(LedgerConnectEventsEnum.CONNECT_DEVICE) });
    }
    accessWallet() {
        this.ledgerConnectBase.accessWallet();
    }
    selectAccount(index) {
        this.ledgerConnectBase.selectAccount(index);
        this.selectedIndex = this.ledgerConnectBase.selectedIndex;
    }
    async nextPage() {
        this.ledgerConnectBase.nextPage();
    }
    async prevPage() {
        this.ledgerConnectBase.prevPage();
    }
    removeComponent() {
        var _a;
        if ((_a = this.hostElement) === null || _a === void 0 ? void 0 : _a.parentNode) {
            this.hostElement.parentNode.removeChild(this.hostElement);
        }
    }
    getEventSubscription() {
        return {
            closeFn: () => this.removeComponent(),
            forceUpdateFn: () => {
                this.data = this.ledgerConnectBase.data;
                forceUpdate(this);
            },
        };
    }
    componentDidLoad() {
        this.ledgerConnectBase.subscribeEventBus(this.getEventSubscription());
    }
    disconnectedCallback() {
        this.ledgerConnectBase.unsubscribeEventBus(this.getEventSubscription());
    }
    get hostElement() { return getElement(this); }
};

export { LedgerConnect as mvx_ledger_connect };
//# sourceMappingURL=mvx-ledger-connect.entry.js.map

//# sourceMappingURL=mvx-ledger-connect.entry.js.map